pub struct ClassBuilder { /* private fields */ }Expand description
Builder for class types
Note: All methods are fallible because the underlying class could be deleted while you hold a reference to the builder.
Implementations
Sourceimpl ClassBuilder
impl ClassBuilder
Sourcepub fn add_property(
&self,
name: &str,
field_type: &TypeDef,
) -> Result<ClassPropertyBuilder, BamlError>
pub fn add_property( &self, name: &str, field_type: &TypeDef, ) -> Result<ClassPropertyBuilder, BamlError>
Add a property to this class
Sourcepub fn get_property(&self, name: &str) -> Option<ClassPropertyBuilder>
pub fn get_property(&self, name: &str) -> Option<ClassPropertyBuilder>
Get a property by name (if it exists)
Sourcepub fn list_properties(&self) -> Result<Vec<ClassPropertyBuilder>, BamlError>
pub fn list_properties(&self) -> Result<Vec<ClassPropertyBuilder>, BamlError>
List all properties