pub struct TypeBuilder { /* private fields */ }Expand description
Builder for constructing BAML types at runtime
Implementations
Sourceimpl TypeBuilder
impl TypeBuilder
Sourcepub fn literal_string(&self, value: &str) -> TypeDef
pub fn literal_string(&self, value: &str) -> TypeDef
Get a literal string type
Sourcepub fn literal_int(&self, value: i64) -> TypeDef
pub fn literal_int(&self, value: i64) -> TypeDef
Get a literal int type
Sourcepub fn literal_bool(&self, value: bool) -> TypeDef
pub fn literal_bool(&self, value: bool) -> TypeDef
Get a literal bool type
Sourcepub fn optional(&self, inner: &TypeDef) -> TypeDef
pub fn optional(&self, inner: &TypeDef) -> TypeDef
Get an optional type containing the given inner type
Sourcepub fn map(&self, key: &TypeDef, value: &TypeDef) -> TypeDef
pub fn map(&self, key: &TypeDef, value: &TypeDef) -> TypeDef
Get a map type with the given key and value types
Sourcepub fn add_baml(&self, baml: &str) -> Result<(), BamlError>
pub fn add_baml(&self, baml: &str) -> Result<(), BamlError>
Parse and add BAML schema definitions
Sourcepub fn add_enum(&self, name: &str) -> Result<EnumBuilder, BamlError>
pub fn add_enum(&self, name: &str) -> Result<EnumBuilder, BamlError>
Add a new enum (fallible - name conflicts, invalid names)
Sourcepub fn get_enum(&self, name: &str) -> Option<EnumBuilder>
pub fn get_enum(&self, name: &str) -> Option<EnumBuilder>
Get an enum by name (nullable - may not exist)
Sourcepub fn list_enums(&self) -> Vec<EnumBuilder>
pub fn list_enums(&self) -> Vec<EnumBuilder>
List all enums (infallible)
Sourcepub fn add_class(&self, name: &str) -> Result<ClassBuilder, BamlError>
pub fn add_class(&self, name: &str) -> Result<ClassBuilder, BamlError>
Add a new class (fallible - name conflicts, invalid names)
Sourcepub fn get_class(&self, name: &str) -> Option<ClassBuilder>
pub fn get_class(&self, name: &str) -> Option<ClassBuilder>
Get a class by name (nullable - may not exist)
Sourcepub fn list_classes(&self) -> Vec<ClassBuilder>
pub fn list_classes(&self) -> Vec<ClassBuilder>
List all classes (infallible)